﻿using Microsoft.VisualBasic.FileIO;
using ProjectTourismCompany.Entities;
using ProjectTourismCompany.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectTourismCompany.Forms;

public partial class FormCheck : Form
{
    private readonly ICheckRepository _checkRepository;
    private int _checkId;
    public int Id
    {
        set
        {
            try
            {
                var check = _checkRepository.ReadCheckById(value);
                if (check == null)
                {
                    throw new
                    InvalidDataException(nameof(check));
                }
                textBoxTitle.Text = check.Title;
                dateTimePickerPurchaseDate.Value = check.PurchaseDate;
                numericUpDownPrice.Value = check.Price;

                comboBoxClient.SelectedItem = check.ClientId;

                comboBoxTrip.SelectedItem = check.TripId;
                _checkId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }
    public FormCheck(ICheckRepository checkRepository, IClientRepository clientRepository)
    {
        InitializeComponent();
        _checkRepository = checkRepository ?? throw new ArgumentNullException(nameof(checkRepository));
        
        comboBoxClient.DataSource = clientRepository.ReadClients();
        comboBoxClient.DisplayMember = "Name";
        comboBoxClient.ValueMember = "Id";

        comboBoxTrip.DisplayMember = "Title";
        comboBoxTrip.ValueMember = "Id";
    }
    private void buttonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxTitle.Text) ||
            comboBoxTrip.SelectedIndex < 0 ||
            comboBoxClient.SelectedIndex < 0)
            {
                throw new Exception("Имеются незаполненные поля");
            }
            _checkRepository.CreateCheck(Check.CreateCheck(_checkId, textBoxTitle.Text, dateTimePickerPurchaseDate.Value,
                (int)numericUpDownPrice.Value, (int)comboBoxTrip.SelectedItem!, 
                (int)comboBoxClient.SelectedItem!));
            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e) =>
    Close();


}


